Crate v8_derive

Crate v8_derive 

Re-exports

pub extern crate v8_derive_macros as macros;
pub use from::TryFromValue;
pub use into::IntoValue;
pub use helpers::*;

Modules

errors
from
This module contains the TryFromValue trait which is used to convert a v8::Value into a Rust type.
helpers
into
This module provides a trait to convert a Rust type into a v8 Value.